@@ -24,7 +24,7 @@ has 'store_as_refs' => (
     default => 0
 );
 
-sub is_volitile { 0 }
+sub is_volatile { 0 }
 
 sub BUILD {
     my ($self, $args) = @_;
@@ -120,4 +120,6 @@ Data::Localize::Storage::BerkeleyDB - BerkeleyDB Backend
 
 =head2 set
 
+=head2 is_volatile
+
 =cut
